@@ -300,10 +300,20 @@ class OrionAuthentication(BaseAuthentication):
             token = requests.request("GET", url, headers=headers, data=payload, files=files).json()
         except model.DoesNotExist:
             raise exceptions.AuthenticationFailed(_('Invalid token.'))
-        if not token['user']['is_active']:
-            raise exceptions.AuthenticationFailed(_('User inactive or deleted.'))
+        try:
+            if token['detail']:
+                return exceptions.AuthenticationFailed(_('Invalid token.'))
+        except:
+            try:
+                if not token['user']['is_active']:
+                    return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
+                return token['user'], token['Authorization']
+            except:
+                if not token.user.is_active:
+                    return exceptions.AuthenticationFailed(_('User inactive or deleted.'))
+                return token.user, token.Authorization
+
 
-        return token['user'], token['Authorization']
 
     def authenticate_header(self, request):
         return self.keyword
