@@ -5,7 +5,3 @@ This package provides support for integrating translatable fields into *django-r
 
 # following PEP 440
 __version__ = "2.1"
-
-from fields import *
-from serializers import *
-from utils import *
